==> qtcreator_4.11.0.orig.tar.xz: qt-creator-opensource-src-4.11.0/src/plugins/qmldesigner/components/propertyeditor/gradientpresetdefaultlistmodel.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "gradientpresetdefaultlistmodel.h"
#include "gradientpresetitem.h"

#include <QHash>
#include <QByteArray>
#include <QDebug>
#include <QFile>

GradientPresetDefaultListModel::GradientPresetDefaultListModel(QObject *parent)
    : GradientPresetListModel(parent)
{
    addAllPresets();
}

GradientPresetDefaultListModel::~GradientPresetDefaultListModel() {}

void GradientPresetDefaultListModel::registerDeclarativeType()
{
    qmlRegisterType<GradientPresetDefaultListModel>("HelperWidgets",
                                                    2,
                                                    0,
                                                    "GradientPresetDefaultListModel");
}

void GradientPresetDefaultListModel::addAllPresets()
{
    const QMetaObject &metaObj = QGradient::staticMetaObject;
    const QMetaEnum metaEnum = metaObj.enumerator(metaObj.indexOfEnumerator("Preset"));

    if (!metaEnum.isValid())
        return;

    for (int i = 0; i < metaEnum.keyCount(); i++) {
        addItem(GradientPresetItem(GradientPresetItem::Preset(metaEnum.value(i))));
    }
}

==> qtcreator_6.0.2.orig.tar.xz: qt-creator-opensource-src-6.0.2/src/plugins/qmldesigner/components/propertyeditor/gradientpresetdefaultlistmodel.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "gradientpresetdefaultlistmodel.h"
#include "gradientpresetitem.h"

#include <QHash>
#include <QByteArray>
#include <QDebug>
#include <QFile>

GradientPresetDefaultListModel::GradientPresetDefaultListModel(QObject *parent)
    : GradientPresetListModel(parent)
{
    addAllPresets();
}

GradientPresetDefaultListModel::~GradientPresetDefaultListModel() {}

void GradientPresetDefaultListModel::registerDeclarativeType()
{
    qmlRegisterType<GradientPresetDefaultListModel>("HelperWidgets",
                                                    2,
                                                    0,
                                                    "GradientPresetDefaultListModel");
}

void GradientPresetDefaultListModel::addAllPresets()
{
    const QMetaObject &metaObj = QGradient::staticMetaObject;
    const QMetaEnum metaEnum = metaObj.enumerator(metaObj.indexOfEnumerator("Preset"));

    if (!metaEnum.isValid())
        return;

    for (int i = 0; i < metaEnum.keyCount(); i++) {
        auto preset = GradientPresetItem::Preset(metaEnum.value(i));
        if (preset < GradientPresetItem::numPresets)
            addItem(GradientPresetItem(preset));
    }
}
